==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt滑鼠游標主題設定</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>選擇您喜歡的游標主題 (檢視來回移動來測試游標) 。
&lt;b&gt;套用改變需要重新啟動LXQt會話&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>安裝新主題...(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">設為主題(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>移除主題(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">關閉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme錯誤</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>您無法移除正在套用的主題!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_TW">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt滑鼠游標主題設定</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>選擇您喜歡的游標主題 (檢視來回移動來測試游標) 。&lt;br&gt;&lt;b&gt;套用改變需要重新啟動LXQt會話&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>安裝新主題...(&amp;I)</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">設為主題(&amp;S)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>移除主題(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">關閉(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="212"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme錯誤</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="213"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>您無法移除正在套用的主題!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
</context>
</TS>
